@@ -1,6 +1,6 @@
 package Object::Simple;
 
-our $VERSION = '3.15';
+our $VERSION = '3.16';
 
 use strict;
 use warnings;
@@ -75,10 +75,12 @@ sub import {
     
     # Export methods
     for my $method (@methods) {
-      
+
       # Can be Exported?
       Carp::croak("Cannot export '$method'.")
         unless $exports{$method};
+
+      warn "function exporting of $method is DEPRECATED(Object::Simple)";
       
       # Export
       no strict 'refs';
@@ -101,7 +103,11 @@ sub attr {
   unshift @args, (shift @args, undef) if @args % 2;
   
   for (my $i = 0; $i < @args; $i += 2) {
-      
+    
+    if ($i == 2) {
+      warn "The syntax of multiple key-value arguments is DEPRECATED(Object::Simple::has or Object::Simple::attr)";
+    }
+    
     # Attribute name
     my $attrs = $args[$i];
     $attrs = [$attrs] unless ref $attrs eq 'ARRAY';
@@ -564,13 +570,11 @@ you can get default value.
 If a value is set, the accessor return self object.
 So you can set a value repeatedly.
 
- $obj->foo(1)->bar(2);
+  $obj->foo(1)->bar(2);
 
 You can create all accessors at once.
 
-  has [qw/foo bar baz/],
-    pot => 1,
-    mer => sub { 5 };
+  has [qw/foo bar baz/];
 
 =head1 METHODS
 
@@ -589,17 +593,20 @@ hash or hash reference as arguments.
   __PACKAGE__->attr(foo => 1);
   __PACKAGE__->attr(foo => sub { {} });
 
-  __PACKAGE__->attr(
-    [qw/foo bar baz/],
-    pot => 1,
-    mer => sub { 5 }
-  );
+  __PACKAGE__->attr([qw/foo bar baz/]);
 
 Create accessor.
 C<attr> method usage is equal to C<has> method.
 
 =head1 DEPRECATED FUNCTIONALITY
 
+  function exporting of C<new> and C<attr> method # Will be removed 2021/6/1
+  
+  The syntax of multiple key-value arguments 
+    has x => 1, y => 2;      
+    __PACAKGE__->attr(x => 1, y => 2);
+  # Will be removed 2021/6/1
+  
   class_attr method # will be removed 2017/1/1
   dual_attr method # will be removed 2017/1/1
 
